function [s,w]=scalwav(n,j,k)

%SCALWAV(N,J,K)    Grafica la funcio d'escala i el wavelet
%            N: ordre del filtre de Daubechies =2,4,6,...
%            J: resultat amb 2^J valors
%            K: passos d'inversio de la transformada

[h,g,hr,gr]=daub(n);

st=[1 zeros(1,2^j-1)];

%r=2^(j-k-1);
r=1;
if (r<1)  r=1; end
wt=zeros(1,2^j);
wt(2^(j-k)+r)=1;

s=2^(k/2)*iwt(st,hr,gr,k);
w=2^(k/2)*iwt(wt,hr,gr,k);

titols=['Scale function - Daubechies n=' int2str(n)];
titolw=['Wavelet function - Daubechies n=' int2str(n)];

subplot(1,2,1),plot(1:length(s),s),axis square, xlabel('t'),ylabel('\Phi(t)'),title(titols)
subplot(1,2,2),plot(1:length(w),w),axis square,xlabel('t'),ylabel('\Psi(t)'),title(titolw)

